@@ -30,6 +30,7 @@
 #include "isettings.h"
 #include "iaccels.h"
 #include "inotebook.h"
+#include "imkdir.h"
 
 #include "language.h"
 
@@ -140,6 +141,7 @@ static struct lcrt_language_config iconnect = {
          {"c_delete",                        "Eine Sitzung löschen"},
          {"c_find",                          "Eine Sitzung finden"},
          {"c_session_option",                "Sitzungs-_Optionen"},
+         {"c_mkdir",                         "Neuen Ordner erstellen"},
          {"c_session",                       "Sitzungen"},
          {"c_show_dialog_on_startup",        "_Startdialog anzeigen"},
          {"c_connect_button",                "Verbinden"},
@@ -255,6 +257,19 @@ static struct lcrt_language_config irename = {
     }
 };
 
+static struct lcrt_language_config imkdir = {
+    .table_name = LCRT_IMKDIR_TABLE,
+    .members = LCRT_M_NUMBER,
+    .config = {
+         {"m_title",                            "Neuer Ordner"},
+         {"m_tip",                              "Geben Sie den neuen Ordnernamen:"},
+         {"m_cancel",                           "Abbrechen"},
+         {"m_ok",                               "OK"},
+         {"m_error",                            "Angegebener Name bereits vorhanden!"},
+         {"m_err_msg",                          "Keine Daten zum Speichern vorhanden"},
+    }
+};
+
 static struct lcrt_language_config istatus = {
     .table_name = LCRT_ISTATUS_TABLE,
     .members = LCRT_S_NUMBER,
@@ -326,6 +341,7 @@ static struct lcrt_language_config iaccels = {
         {"kb_edit",                             "Bearbeiten"},
         {"kb_e_copy",                           "Kopieren"},
         {"kb_e_paste",                          "Einfügen"},
+        {"kb_e_find",                           "Finden"},
         {"kb_session",                          "Sitzung"},
         {"kb_s_clone",                          "Kopieren"},
         {"kb_s_close",                          "Schliessen"},
@@ -349,6 +365,21 @@ static struct lcrt_language_config iterminal = {
         {"tm_serial_error",                     "Kann nicht geöffnet werden \"%s\",%s."},
     }
 };
+static struct lcrt_language_config ifind = {
+    .table_name = LCRT_IFIND_TABLE,
+    .members = LCRT_I_NUMBER,
+    .config = {
+        {"i_title",                              "Finden"},
+        {"i_tip_connect",                        "Geben Sie den Namen der Session finden Sie:"},
+        {"i_tip_edit",                           "Geben Sie die Zeichenfolge finden Sie:"},
+        {"i_cancel",                             "Abbrechen"},
+        {"i_prev",                               "Vorherige"},
+        {"i_next",                               "Nächste"},
+        {"i_info",                               "Es gibt nichts zu finden!"},
+        {"i_err_msg",                            "Keine Daten zum Speichern vorhanden"},
+    }
+};
+
 struct lcrt_language de_DE = {
     .language_name = "Deutsch",
     .db_name       = "de_DE.db",
@@ -365,9 +396,11 @@ struct lcrt_language de_DE = {
         &ipopup,
         &iqconnect,
         &irename,
+        &imkdir,
         &istatus,
         &isettings,
         &iaccels,
         &iterminal,
+        &ifind,
     },
 };
