@@ -30,6 +30,7 @@
 #include "isettings.h"
 #include "iaccels.h"
 #include "inotebook.h"
+#include "imkdir.h"
 
 #include "language.h"
 
@@ -140,6 +141,7 @@ static struct lcrt_language_config iconnect = {
          {"c_delete",                        "Delete a session"},
          {"c_find",                          "Find a session"},
          {"c_session_option",                "Session option"},
+         {"c_mkdir",                         "Create new folder"},
          {"c_session",                       "Sessions"},
          {"c_show_dialog_on_startup",        "_Show dialog on startup"},
          {"c_connect_button",                "Connect"},
@@ -256,6 +258,19 @@ static struct lcrt_language_config irename = {
     }
 };
 
+static struct lcrt_language_config imkdir = {
+    .table_name = LCRT_IMKDIR_TABLE,
+    .members = LCRT_M_NUMBER,
+    .config = {
+         {"m_title",                            "New folder"},
+         {"m_tip",                              "Enter new folder name:"},
+         {"m_cancel",                           "Cancel"},
+         {"m_ok",                               "OK"},
+         {"m_error",                            "There has a same one, try an another!"},
+         {"m_err_msg",                          "There is no memory to create dialog"},
+    }
+};
+
 static struct lcrt_language_config istatus = {
     .table_name = LCRT_ISTATUS_TABLE,
     .members = LCRT_S_NUMBER,
@@ -327,6 +342,7 @@ static struct lcrt_language_config iaccels = {
         {"kb_edit",                             "Edit"},
         {"kb_e_copy",                           "Copy"},
         {"kb_e_paste",                          "Paste"},
+        {"kb_e_find",                           "Find"},
         {"kb_session",                          "Session"},
         {"kb_s_clone",                          "Clone"},
         {"kb_s_close",                          "Close"},
@@ -350,6 +366,21 @@ static struct lcrt_language_config iterminal = {
         {"tm_serial_error",                     "Can't open \"%s\",%s."},
     }
 };
+static struct lcrt_language_config ifind = {
+    .table_name = LCRT_IFIND_TABLE,
+    .members = LCRT_I_NUMBER,
+    .config = {
+        {"i_title",                              "Find"},
+        {"i_tip_connect",                        "Enter the name of session you want find:"},
+        {"i_tip_edit",                           "Enter the string you want find:"},
+        {"i_cancel",                             "Cancel"},
+        {"i_prev",                               "Previous"},
+        {"i_next",                               "Next"},
+        {"i_info",                               "There is nothing find!"},
+        {"i_err_msg",                            "There is no memory to create dialog"},
+    }
+};
+
 struct lcrt_language en_US = {
     .language_name = "English",
     .db_name       = "en_US.db",
@@ -366,9 +397,11 @@ struct lcrt_language en_US = {
         &ipopup,
         &iqconnect,
         &irename,
+        &imkdir,
         &istatus,
         &isettings,
         &iaccels,
         &iterminal,
+        &ifind,
     },
 };
