@@ -23,9 +23,15 @@ void lcrt_statusbar_set_user(struct lcrt_statusbar *lstatusbar, struct lcrtc_use
     if (user == NULL)
         return;
 
-     lcrt_statusbar_set_message(lstatusbar,
-                                "[%s] %s@%s", 
+    if (!user->is_folder)
+         lcrt_statusbar_set_message(lstatusbar,
+                                "[%s] %s@%s %d", 
                                 proto[user->protocol],
                                 user->username,
-                                user->hostname);
+                                user->hostname,
+				user->port);
+    else
+         lcrt_statusbar_set_message(lstatusbar,
+                                "[FOLDER]: %s", 
+                                user->folder);
 }
