@@ -1,9 +1,16 @@
 /**
  * @file    foperate.c
- * @brief   file operate functions
- * @author  niu.tao
+ * <h2>License</h2>
+ * Copyright (c) 2012 ~ Niu Tao
+ *
+ * This source code is released for free distribution under the terms of the
+ * GNU General Public License
+ *
+ * @author  Niu Tao <niutao0602@gmail.com>
  * @version v1.0
  * @date    2010-11-16
+ *
+ * @brief  The functions below are written for file operation.
  */
 #include <stdio.h>
 #include <sys/types.h>
@@ -15,7 +22,14 @@
 #include <stdarg.h>
 #include <stdlib.h>
 
-int lcrt_mkdir(const char *dir)
+/**
+ * @brief  Create directory from root, if the parent directory is not exist,
+ *         then make it until last one.
+ * @param dir path or directory which want to create
+ * @return = 0, success\n
+ *         < 0, error code
+ */
+int lcrt_fmkdir(const char *dir)
 {
     int len;
     struct stat st;
@@ -24,12 +38,15 @@ int lcrt_mkdir(const char *dir)
 
     if (dir == NULL)
         return -EINVAL;
+    /** the directory has exist, so ship  */
     if (access(dir, F_OK | R_OK | W_OK) == 0)
         return 0;
+
     strncpy(logdir,dir ,512);
     len = strlen(logdir);
+
     if (len == 0)
-        return -1;
+        return -EINVAL;
 
     p = logdir + len - 1;
     while (*p == '/')
@@ -61,7 +78,14 @@ int lcrt_mkdir(const char *dir)
     return 0;
 }
 
-int lcrt_copy(const char *fsrc, const char *fdst)
+/**
+ * @brief  copy a file from fsrc to fdst
+ * @param fsrc the source file name which will be copy
+ * @param fdst the target file name which will be generate
+ * @return = 0, success\n
+ *         < 0, error code
+ */
+int lcrt_fcopy(const char *fsrc, const char *fdst)
 {
     unsigned char buffer[4096];
     FILE *fps, *fpd;
@@ -96,7 +120,14 @@ out:
     return rv;
 }
 
-int lcrt_dircopy(const char *dsrc, const char *ddst)
+/**
+ * @brief  copy a directory from another
+ * @param dsrc the source directory name
+ * @param ddst the target directory name
+ * @return = 0, success\n
+ *         < 0, error code
+ */
+int lcrt_fdircopy(const char *dsrc, const char *ddst)
 {
     DIR *dir;
     struct dirent *direntp;
@@ -116,35 +147,50 @@ int lcrt_dircopy(const char *dsrc, const char *ddst)
         rv = -errno;
         goto out;
     }
-    lcrt_mkdir(ddst);
+    lcrt_fmkdir(ddst);
     while ((direntp = readdir(dir)) != NULL) {
         if (strcmp(direntp->d_name, ".") == 0 || strcmp(direntp->d_name, "..") == 0)
             continue;
         if (direntp->d_type == DT_DIR) {
             snprintf(fsrc, sizeof(fsrc), "%s/%s", dsrc, direntp->d_name);
             snprintf(fdst, sizeof(fdst), "%s/%s", ddst, direntp->d_name);
-            lcrt_mkdir(fdst);
-            lcrt_dircopy(fsrc, fdst);
+            lcrt_fmkdir(fdst);
+            lcrt_fdircopy(fsrc, fdst);
             continue;
         }
         snprintf(fsrc, sizeof(fsrc), "%s/%s", dsrc, direntp->d_name);
         snprintf(fdst, sizeof(fdst), "%s/%s", ddst, direntp->d_name);
-        lcrt_copy(fsrc, fdst);
+        lcrt_fcopy(fsrc, fdst);
     }
     closedir(dir);
 out:
     return rv;
 }
-int lcrt_move(const char *fsrc, const char *fdst)
+
+/**
+ * @brief  move a file to another path
+ * @param fsrc the source file name
+ * @param fdst the target file name
+ * @return = 0, success\n
+ *         < 0, error code
+ */
+int lcrt_fmove(const char *fsrc, const char *fdst)
 {
     int rv;
 
-    if ((rv = lcrt_copy(fsrc, fdst)) == 0) {
+    if ((rv = lcrt_fcopy(fsrc, fdst)) == 0) {
         unlink(fsrc);
     }
     return rv;
 }
-int lcrt_remove(const char *fname)
+
+/**
+ * @brief  delete a file
+ * @param fname the file name which will be deleted
+ * @return = 0, success\n
+ *         < 0, error code
+ */
+int lcrt_fremove(const char *fname)
 {
     if (fname == NULL)
         return -EINVAL;
@@ -154,6 +200,15 @@ int lcrt_remove(const char *fname)
 
     return 0;
 }
+
+/**
+ * @brief  print some content to the end of file
+ * @param fname the file name
+ * @param format the format of content
+ * @param ... the argument
+ * @return = 0, success\n
+ *         < 0, error code
+ */
 int lcrt_fappend(const char *fname, const char *format, ...)
 {
     va_list args;
@@ -177,6 +232,12 @@ int lcrt_fappend(const char *fname, const char *format, ...)
     return rv;
 }
 
+/**
+ * @brief  create a file
+ * @param fname the file name which will be created
+ * @return = 0, success\n
+ *         < 0, error code
+ */
 int lcrt_fcreate(const char *fname)
 {
     FILE *fp;
@@ -191,8 +252,14 @@ int lcrt_fcreate(const char *fname)
 
     return 0;
 }
-
-int lcrt_echeck(const char *prog)
+/**
+ * @brief  check whether the executive programe is exist in directory 'PATH'
+ * @param prog the executive programe name
+ * @param p_path if found, store path to p_path
+ * @return = 0, exist in directory 'PATH'
+ *         < 0, error code
+ */
+int lcrt_echeck(const char *prog, char *p_path)
 {
     char *env;
     char *vpath, *path;
@@ -214,6 +281,7 @@ int lcrt_echeck(const char *prog)
         snprintf(buff, sizeof(buff), "%s/%s", path, prog);
         if (access(buff, F_OK | X_OK) == 0) {
             rv = 0;
+	    strcpy(p_path, buff);
             break;
         }
         path = strtok(NULL, ":");
