@@ -1,15 +1,18 @@
-/*
- * Copyright (c) 2010-1011 ~ Niu Tao
+/**
+ * @file serial.c
+ * <h2>License</h2>
+ * Copyright (c) 2010-2011 ~ Niu Tao
  *
  * This source code is released for free distribution under the terms of the
  * GNU General Public License
  *
- * Author      : NiuTao<niutao0602@gmail.com>
- * Created Time: Sat 06 Aug 2011 10:55:20 PM CST
- * File Name   : serial.c
+ * @author Niu Tao <niutao0602@gmail.com>
+ * @version $Id
+ * @date Sat 06 Aug 2011 10:55:20 PM CST
  *
- * Description:  
+ * @brief  
  */
+
 //#define __LCRT_DEBUG__
 #include <stdio.h>
 #include <string.h>
@@ -31,6 +34,7 @@
 #include "message.h"
 #include "cstatusbar.h"
 
+#if 0
 /**
  * fix compile error in hurd-i386, kfreebsd-amd64,
  * kfreebsd-i386, mips, mipsel
@@ -38,6 +42,10 @@
 #ifndef CMSPAR
 #define CMSPAR 010000000000
 #endif
+#ifndef CBAUD
+#define CBAUD  0010017
+#endif
+#endif
 
 struct lcrt_serial_map {
     int index;
@@ -105,9 +113,11 @@ int lcrt_serial_config(const char *port, int baud_rate, int databit,
         return -errno;
     }
     //tcgetattr(fd, &ltermios);
-	memset(&ltermios, 0, sizeof(struct termios));
-#if 1
+    memset(&ltermios, 0, sizeof(struct termios));
+#ifdef CBAUD
     ltermios.c_cflag |= (baud_rate & CBAUD);
+#endif
+#ifdef CSIZE
     ltermios.c_cflag |= (databit & CSIZE);
 #endif
     switch (stopbit) {
@@ -135,12 +145,14 @@ int lcrt_serial_config(const char *port, int baud_rate, int databit,
     case 2:
         ltermios.c_cflag |= PARENB; /* Enable parity */
         break;
+#ifdef CMSPAR
     case 3:
         ltermios.c_cflag &= ~CMSPAR;
         break;
     case 4:
         ltermios.c_cflag |= CMSPAR;
         break;
+#endif
     default:
         return -EINVAL;
     }
@@ -180,13 +192,11 @@ static void lcrt_serial_read(gpointer user_data, gint fd, GdkInputCondition cond
     debug_where();
     len = read(fd, buffer, 1024);
     if (len <= 0) {
-		/** serial device may be pull out  */
-		if (errno == EAGAIN) {
-			lcrt_serial_disconnect(lterminal);
-			return;
-		}
-		printf("ERRNO = %d\n", errno);
-        perror(__func__);
+        /** serial device may be pull out  */
+        if (errno == EAGAIN) {
+            lcrt_serial_disconnect(lterminal);
+            return;
+        }
         return ;
     }
     vte_terminal_feed(VTE_TERMINAL(lterminal->terminal), (const char *)buffer, len);
@@ -249,7 +259,7 @@ static int lcrt_serial_connect(struct lcrt_terminal *lterminal)
                      G_CALLBACK(lcrt_serial_write), lterminal);
     lcrt_statusbar_set_user(lterminal->parent->parent->w_statusbar, lterminal->user);
     lcrt_terminal_set_connected_status(lterminal);
-	return LCRTE_OK;
+    return LCRTE_OK;
 }
 
 static void lcrt_serial_disconnect(struct lcrt_terminal *lterminal)
@@ -302,10 +312,10 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     static struct lcrt_serial_if slserial, *lserial = &slserial;
     struct lcrtc_user *user = NULL;
     char s_port[USERNAME_LEN];
-	boolean f_option = FALSE;
+    boolean f_option = FALSE;
     int s_baud_rate,s_databit,s_parity,s_stopbit,s_software,s_hardware;
-	if (lqconnect->flag == LCRT_QCONNECT_SESSION_OPTION &&
-    	(user = lcrt_user_find_by_name(&lqconnect->parent->u_config, lqconnect->uname)) != NULL) {
+    if (lqconnect->flag == LCRT_QCONNECT_SESSION_OPTION &&
+        (user = lcrt_user_find_by_name(&lqconnect->parent->u_config, lqconnect->uname)) != NULL) {
         sscanf(user->password, "%s %d %d %d %d %d %d", 
                 s_port,
                 &s_baud_rate,
@@ -323,8 +333,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
                 s_software,
                 s_hardware);
 
-		f_option = TRUE;
-	}
+        f_option = TRUE;
+    }
 
     memset(lserial, 0, sizeof(struct lcrt_serial_if));
     lqconnect->private_data = lserial;
@@ -357,8 +367,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     
     for (i = 0; i < LCRT_SERIAL_PORT_NUMBER; i++) {
         gtk_combo_box_append_text (GTK_COMBO_BOX (combobox_port), sport[i]);
-		if (f_option && strcmp(s_port, sport[i]) == 0)
-			gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_port), i);
+        if (f_option && strcmp(s_port, sport[i]) == 0)
+            gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_port), i);
 
     }
     debug_where();
@@ -383,8 +393,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     
     for (i = 0; i < LCRT_SERIAL_BAUD_RATE_NUMBER; i++) {
         gtk_combo_box_append_text (GTK_COMBO_BOX (combobox_baud_rate), sbaud_rate[i].name);
-		if (f_option && s_baud_rate == sbaud_rate[i].data)
-			gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_baud_rate), i);
+        if (f_option && s_baud_rate == sbaud_rate[i].data)
+            gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_baud_rate), i);
     }
     debug_where();
     gtk_entry_set_editable(GTK_ENTRY(GTK_BIN(combobox_baud_rate)->child), FALSE);
@@ -408,8 +418,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     
     for (i = 0; i < LCRT_SERIAL_DATA_BITS_NUMBER; i++) {
         gtk_combo_box_append_text (GTK_COMBO_BOX (combobox_data_bits), sdata_bits[i].name);
-		if (f_option && s_databit == sdata_bits[i].data)
-			gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_data_bits), i);
+        if (f_option && s_databit == sdata_bits[i].data)
+            gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_data_bits), i);
     }
     debug_where();
     gtk_entry_set_editable(GTK_ENTRY(GTK_BIN(combobox_data_bits)->child), FALSE);
@@ -434,8 +444,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     for (i = 0; i < LCRT_SERIAL_PARITY_NUMBER; i++) {
         gtk_combo_box_append_text (GTK_COMBO_BOX (combobox_parity), sparity[i].name);
     }
-	if (f_option)
-		gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_parity), s_parity);
+    if (f_option)
+        gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_parity), s_parity);
     debug_where();
     gtk_entry_set_editable(GTK_ENTRY(GTK_BIN(combobox_parity)->child), FALSE);
 
@@ -459,8 +469,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     for (i = 0; i < LCRT_SERIAL_STOP_BITS_NUMBER; i++) {
         gtk_combo_box_append_text (GTK_COMBO_BOX (combobox_stop_bits), sstop_bits[i].name);
     }
-	if (f_option)
-		gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_stop_bits), s_stopbit);
+    if (f_option)
+        gtk_combo_box_set_active(GTK_COMBO_BOX(combobox_stop_bits), s_stopbit);
     debug_where();
     gtk_entry_set_editable(GTK_ENTRY(GTK_BIN(combobox_stop_bits)->child), FALSE);
 
@@ -485,8 +495,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     gtk_box_pack_start (GTK_BOX (hbox_frame), checkbutton_software, FALSE, FALSE, 0);
     gtk_widget_set_size_request (checkbutton_software, 150, -1);
 
-	if (f_option)
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_software), s_software);
+    if (f_option)
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_software), s_software);
 
     checkbutton_hardware = gtk_check_button_new_with_mnemonic (flow_control[1].name);
     lserial->hardware = checkbutton_hardware;
@@ -494,8 +504,8 @@ static void lcrt_serial_show(struct lcrt_qconnect *lqconnect)
     gtk_box_pack_start (GTK_BOX (hbox_frame), checkbutton_hardware, FALSE, FALSE, 0);
     gtk_widget_set_size_request (checkbutton_hardware, 150, -1);
 
-	if (f_option)
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_hardware), s_hardware);
+    if (f_option)
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_hardware), s_hardware);
 
     label_flow_control = gtk_label_new (lqconnect->config.value[LCRT_Q_SFLOW_CONTROL]);
     gtk_widget_show (label_flow_control);
@@ -520,7 +530,7 @@ static struct lcrtc_user *lcrt_serial_create(struct lcrt_qconnect *lqconnect)
     struct lcrt_window *lwindow = lqconnect->parent;
     struct lcrt_serial_if *lserial = (struct lcrt_serial_if *)lqconnect->private_data;
     struct lcrt_serial_map serial_buad_rate[] = {LCRT_SERIAL_BAUD_RATE_TABLE};
-	struct lcrt_serial_map serial_databit[] = {LCRT_SERIAL_DATA_BITS_TABLE};
+    struct lcrt_serial_map serial_databit[] = {LCRT_SERIAL_DATA_BITS_TABLE};
     struct lcrtc_user *user;
     char password[PASSWORD_LEN];
     char s_port[USERNAME_LEN];
@@ -599,7 +609,9 @@ static struct lcrtc_user *lcrt_serial_create(struct lcrt_qconnect *lqconnect)
            password,
            gtk_entry_get_text(GTK_ENTRY(lqconnect->q_et_default_command)),
            0,
-           TRUE
+           TRUE,
+           lqconnect->folder,
+           0
         );
         lcrtc_user_ref(user);
         lcrt_user_add(&lwindow->u_config, user);
@@ -618,7 +630,9 @@ static struct lcrtc_user *lcrt_serial_create(struct lcrt_qconnect *lqconnect)
                password,
                gtk_entry_get_text(GTK_ENTRY(lqconnect->q_et_default_command)),
                0,
-               TRUE
+               TRUE,
+               NULL,
+               -1
             );
         }
     }
