@@ -203,6 +203,9 @@ static int lcrt_ssh_connect(struct lcrt_terminal *lterminal)
     int dep = -1;
     char tmp[32];
     struct lcrt_ssh_tm *tssh;
+#if VTE_CHECK_VERSION(0, 26, 0)
+    char path[512];
+#endif
 
     if (lterminal == NULL)
        return -EINVAL;
@@ -235,9 +238,24 @@ static int lcrt_ssh_connect(struct lcrt_terminal *lterminal)
                           argv[0]);
         return -LCRTE_NOT_FOUND;
     }
-
+#if VTE_CHECK_VERSION(0, 26, 0)
+    lcrt_echeck(argv[0], path);
+    argv[0] = path;
+    vte_terminal_fork_command_full(
+                            VTE_TERMINAL(lterminal->terminal), 
+                            VTE_PTY_DEFAULT,
+                            work_dir,
+                            argv, 
+                            NULL, 
+                            0, 
+                            NULL, 
+                            NULL,
+                            &lterminal->child_pid, 
+                            NULL);
+#else
     lterminal->child_pid  = vte_terminal_fork_command(VTE_TERMINAL(lterminal->terminal), 
                 argv[0], argv, NULL , work_dir, FALSE, FALSE, FALSE);
+#endif
     debug_print("child_pid = %d\n", lterminal->child_pid);
     lcrt_statusbar_set_user(lterminal->parent->parent->w_statusbar, lterminal->user);
     debug_where();
@@ -389,7 +407,9 @@ void lcrt_ssh_password_on_okbutton_clicked(GtkButton *button, gpointer user_data
        gtk_entry_get_text(GTK_ENTRY(lssh->ext[1])),
        NULL,
        -1,
-       1
+       1,
+       NULL,
+       -1
        );
     lcrt_ssh_password_on_cancelbutton_clicked(NULL, lqconnect);
     if (lcrt_window_get_auto_save(lqconnect->parent)) {
@@ -574,29 +594,6 @@ static void lcrt_ssh_on_button_properties_clicked(GtkButton *button, gpointer us
         if (lcrt_ssh_auth->auth == TRUE && 
             lqconnect->flag == LCRT_QCONNECT_SESSION_OPTION)
             lcrt_ssh_auth->callback(lcrt_ssh_auth->user_data);
-#if 0
-        printf("selected = %d\n", *selected);
-        gtk_tree_model_get(model, &iter, 1, &value, -1);
-        printf("text = %s\n", value);
-        g_free(value);
-#endif
-#if 0
-        lcrt_create_dialog_rename(lwindow, GTK_WINDOW(lterminal->c_connect), value, FALSE);
-        if (strcmp(lwindow->current_uname, "") != 0) {
-            if ((user = lcrt_user_find_by_name(&lwindow->u_config, value)) != NULL) {
-                if (lcrt_window_get_auto_save(lwindow)) {
-                    rv = lcrt_user_rename(&lwindow->u_config, user, lwindow->current_uname);
-                    if (rv == LCRTE_OK) {
-                        g_value_set_string(&gvalue, lwindow->current_uname);
-                        gtk_tree_store_set_value(
-                                GTK_TREE_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW (treeview))),
-                                &iter, 0, &gvalue);
-                    }
-                }
-            }
-            memset(lwindow->current_uname, 0, HOSTNAME_LEN);
-        }
-#endif
     } 
 
 }
@@ -891,7 +888,9 @@ static struct lcrtc_user *lcrt_ssh_create(struct lcrt_qconnect *lqconnect)
            NULL,
            gtk_entry_get_text(GTK_ENTRY(lqconnect->q_et_default_command)),
            atoi(gtk_entry_get_text(GTK_ENTRY(lssh->port))),
-           TRUE
+           TRUE,
+           lqconnect->folder,
+           0
         );
         lcrtc_user_ref(user);
         lcrt_user_add(&lwindow->u_config, user);
@@ -910,7 +909,9 @@ static struct lcrtc_user *lcrt_ssh_create(struct lcrt_qconnect *lqconnect)
                NULL,
                gtk_entry_get_text(GTK_ENTRY(lqconnect->q_et_default_command)),
                atoi(gtk_entry_get_text(GTK_ENTRY(lssh->port))),
-               TRUE
+               TRUE,
+               NULL,
+               -1
             );
         }
     }
